%
% Controle de velocidade angular do motor eletrico CC
% Testes com controle PI H(z)=
%
% Utilizar os parametros no dominio continuo 's'
% obtidos na Exp. 3 ou os parametros obtidos
% na Exp. 4 mas convertidos para o tempo continuo:
% (a1,b1) --> (Kp,T)
% Lembre-se que os parametros (a1,b1) estimados na Exp. 4 so valem
% para fa=50Hz-->Ta=0.02s
% Convertendo inicialmente para o tempo continuo
% podemos posteriormente converte-lo para um modelo discreto
% com valor qq de Ta
Kw = 1.0;
T  = 0.25;
%
% Definicao do intervalo de amostragem
Ta = 0.02;
% Sistema definido no dominio continuo
Gs = tf([Kw],[T 1]);
% Conversao para o dominio discreto utilizando Ta
% Metodo de conversao Zero-th Order Hold
Gz = c2d(Gs,Ta,'zoh');
%
% Definicao do controlador PI H(z)=Kp(1+Ta/Ti*1/(z-1))
% Escolha de ganhos
%
Kp1 = 3; Ti1=0.1; H1z=tf([Ti1 (Ta-Ti1)],[Ti1 -Ti1],Ta)
Kp2 = 3; Ti2=0.5; H2z=tf([Ti2 (Ta-Ti2)],[Ti2 -Ti2],Ta)
Kp3 = 3; Ti3=1.0; H3z=tf([Ti3 (Ta-Ti3)],[Ti3 -Ti3],Ta)
% Definicao da malha aberta
% Sao definidos 3 sistemas distintos
GH1z = Kp1*H1z*Gz;
GH2z = Kp2*H2z*Gz;
GH3z = Kp3*H3z*Gz;

display('Polos e zeros GH1z')
pole(GH1z)
zero(GH1z)
display('Polos e zeros GH2z')
pole(GH2z)
zero(GH2z)
display('Polos e zeros GH3z')
pole(GH3z)
zero(GH3z)

%
% Plot com os polos e zeros de malha aberta
%
figure(1);
subplot(1,3,1);
pzplot(GH1z);
title('m. aberta GH1z');
axis equal;
subplot(1,3,2);
pzplot(GH2z);
title('m. aberta GH2z');
axis equal;
subplot(1,3,3);
pzplot(GH3z);
title('m. aberta GH3z');
axis equal;
print -dpng pzmapopenloopPI.png
%
% definicao da malha fechada
% realimentacao unitaria
%
cloop1 = feedback(GH1z,1);
cloop2 = feedback(GH2z,1);
cloop3 = feedback(GH3z,1);

display('Polos e zeros cloop1')
pole(cloop1)
zero(cloop1)
display('Polos e zeros cloop2')
pole(cloop2)
zero(cloop2)
display('Polos e zeros cloop3')
pole(cloop3)
zero(cloop3)

%
%  Plot com os polos e zeros de malha fechada
%
figure(2);
subplot(1,3,1)
pzplot(cloop1);     
title('m. fechada CL1');
axis equal;
subplot(1,3,2)
pzplot(cloop2);
title('m. fechada CL2');
axis equal;
subplot(1,3,3)
pzplot(cloop3);
title('m. fechada CL3');
axis equal;
print -dpng pzmapcloopPI.png
%
% Grafico da resposta a degrau no dominio de tempo discreto
%
tfinal = 5;
t = 0:Ta:tfinal;
figure(3);
stepplot(cloop1,cloop2,cloop3,t);
grid on
print -dpng respostadegrauacloopPI.png
%
% Caracteristicas da resposta a degrau
% Tr - Tempo de subida, Ts - Tempo de acomodacao, Mp - Maximo sobresinal
%
display('caracteristicas resposta a degrau cloop1')
info=stepinfo(cloop1)
display('caracteristicas resposta a degrau cloop2')
info=stepinfo(cloop2)
display('caracteristicas resposta a degrau cloop3')
info=stepinfo(cloop3)
